==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QGraphicsLayoutItem_shell.h <==
#ifndef QGRAPHICSLAYOUTITEM_IMPL_SHELL_H
#define QGRAPHICSLAYOUTITEM_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayoutitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QGraphicsObject>
#include <QGraphicsWidget>
#include <QObject>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qsizepolicy.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGraphicsLayoutItem_shell : public QGraphicsLayoutItem, public QtJambiShellInterface
{
public:
    QGraphicsLayoutItem_shell(QGraphicsLayoutItem* parent0 = nullptr, bool isLayout1 = false);
    ~QGraphicsLayoutItem_shell() override;

    void getContentsMargins(qreal* left0, qreal* top1, qreal* right2, qreal* bottom3) const override;
    bool isEmpty() const override;
    void setGeometry(const QRectF& rect0) override;
    QSizeF sizeHint(Qt::SizeHint which0, const QSizeF& constraint1) const override;
    void updateGeometry() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsLayoutItem_access : public QGraphicsLayoutItem
{
    void __qt_setGraphicsItem_QGraphicsItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    void __qt_setOwnedByLayout_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean ownedByLayout0);
    void __qt_getContentsMargins_qreal_ptr_qreal_ptr_qreal_ptr_qreal_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdoubleArray left0) const;
    jboolean __qt_isEmpty(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_sizeHint_Qt_SizeHint_cref_QSizeF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint which0, QtJambiNativeID constraint1) const;
    void __qt_updateGeometry(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QGRAPHICSLAYOUTITEM_IMPL_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QGraphicsLayoutItem_shell.h <==
#ifndef QGRAPHICSLAYOUTITEM_IMPL_SHELL_H
#define QGRAPHICSLAYOUTITEM_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <qtwidgets-config.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicslayoutitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtJambi/QtJambiAPI>
#include <QGraphicsObject>
#include <QGraphicsWidget>
#include <QObject>
#include <QtCore/QVariant>
#include <QtCore/qnamespace.h>
#include <QtCore/qrect.h>
#include <QtCore/qsize.h>
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsitem.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qsizepolicy.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QGraphicsLayoutItem_shell : public QGraphicsLayoutItem, public QtJambiShellInterface
{
public:
    QGraphicsLayoutItem_shell(QGraphicsLayoutItem* parent0 = nullptr, bool isLayout1 = false);
    ~QGraphicsLayoutItem_shell() override;

    void getContentsMargins(qreal* left0, qreal* top1, qreal* right2, qreal* bottom3) const override;
    bool isEmpty() const override;
    void setGeometry(const QRectF& rect0) override;
    QSizeF sizeHint(Qt::SizeHint which0, const QSizeF& constraint1) const override;
    void updateGeometry() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsLayoutItem_access : public QGraphicsLayoutItem
{
    void __qt_setGraphicsItem_QGraphicsItem_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    void __qt_setOwnedByLayout_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean ownedByLayout0);
    void __qt_getContentsMargins_qreal_ptr_qreal_ptr_qreal_ptr_qreal_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jdoubleArray left0) const;
    jboolean __qt_isEmpty_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setGeometry_cref_QRectF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID rect0);
    jobject __qt_sizeHint_Qt_SizeHint_cref_QSizeF_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint which0, QtJambiNativeID constraint1) const;
    void __qt_updateGeometry(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QGRAPHICSLAYOUTITEM_IMPL_SHELL_H
